[−][src]Crate space
This library is intended to be incredibly lightweight (cost nothing), but provide common traits that can be shared among spatial data structures.
Structs
| Hamming | Any data contained in this struct is treated such that all of the bits
of the data are each separate dimensions that can be of length |
| IndexIter | An iterator created by calling |
| Indices | This can be used to return an iterable set of indices over a search index
by wrapping any type that implements |
| L1 | L1 distance is applied to items wrapped in this type. |
| L2 | L2 distance is applied to items wrapped in this type. |
| LInfinity | L-infinity distance is applied to items wrapped in this type. |
Traits
| MetricPoint | This trait is implemented by points inside of a metric space. |
Functions
| f32_metric | Converts a |
| f64_metric | Converts a |